# External Dependencies

This file lists the dependencies used in this repository.

| Dependency | License |
|-|-|
| Go | BSD 3-Clause "New" or "Revised" License |
| github.com/nats-io/nats-server/v2 | Apache License 2.0 |
| github.com/golang/protobuf v1.4.2 | BSD 3-Clause "New" or "Revised" License |
| github.com/nats-io/jwt/v2 v2.5.2 | Apache License 2.0 |
| github.com/nats-io/nats.go v1.30.2 | Apache License 2.0 |
| github.com/nats-io/nkeys v0.4.5 | Apache License 2.0 |
| github.com/nats-io/nuid v1.0.1 | Apache License 2.0 |
| golang.org/x/crypto v0.13.0 | BSD 3-Clause "New" or "Revised" License |
| golang.org/x/exp v0.0.0-20230905200255-921286631fa9 | BSD 3-Clause "New" or "Revised" License |
| golang.org/x/sys v0.12.0 | BSD 3-Clause "New" or "Revised" License |
| golang.org/x/time v0.3.0 | BSD 3-Clause "New" or "Revised" License |
| google.golang.org/protobuf v1.23.0 | BSD 3-Clause "New" or "Revised" License |
| github.com/klauspost/compress/s2 v1.17.0 | BSD 3-Clause "New" or "Revised" License |
| github.com/minio/highwayhash v1.0.2 | Apache License 2.0 |
| go.uber.org/automaxprocs v1.5.3 | MIT License |
